@@ -32,17 +32,19 @@ class ThemeEditorMainWindow : public KXmlGuiWindow
     Q_OBJECT
 public:
     explicit ThemeEditorMainWindow();
-    ~ThemeEditorMainWindow();
+    ~ThemeEditorMainWindow() override;
 
 protected:
     void closeEvent(QCloseEvent *) override;
 
+private Q_SLOTS:
+    void slotUploadTheme();
+
 private:
     void slotNewTheme();
     void slotCloseTheme();
     void slotAddExtraPage();
     void slotOpenTheme();
-    void slotUploadTheme();
     void slotQuitApp();
     bool slotSaveTheme();
     void slotConfigure();
